@@ -16,16 +16,12 @@ import (
 	"github.com/hofstadter-io/hof/cmd/hof/ga"
 )
 
-var hofLong = `The High Code Framework`
+var hofLong = `The Higher Order Framework`
 
 func init() {
 
-	RootCmd.PersistentFlags().StringVarP(&(flags.RootPflags.Package), "package", "p", "", "the Cue package context to use during execution")
-	RootCmd.PersistentFlags().StringSliceVarP(&(flags.RootPflags.Tags), "tags", "t", nil, "@tags() to be injected into CUE code")
-	RootCmd.PersistentFlags().IntVarP(&(flags.RootPflags.Verbosity), "verbosity", "v", 0, "set the verbosity of output")
-	RootCmd.PersistentFlags().BoolVarP(&(flags.RootPflags.IncludeData), "include-data", "", false, "auto include all data files found with cue files")
-	RootCmd.PersistentFlags().BoolVarP(&(flags.RootPflags.InjectEnv), "inject-env", "", false, "inject all ENV VARs as default tag vars")
-	RootCmd.PersistentFlags().BoolVarP(&(flags.RootPflags.Quiet), "quiet", "q", false, "turn off output and assume defaults at prompts")
+	flags.SetupRootPflags(RootCmd.PersistentFlags(), &(flags.RootPflags))
+
 }
 
 func RootPersistentPreRun(args []string) (err error) {
@@ -44,7 +40,7 @@ var RootCmd = &cobra.Command{
 
 	Use: "hof",
 
-	Short: "The High Code Framework",
+	Short: "The Higher Order Framework",
 
 	Long: hofLong,
 
@@ -130,8 +126,13 @@ func RootInit() {
 	RootCmd.AddCommand(FlowCmd)
 	RootCmd.AddCommand(FmtCmd)
 	RootCmd.AddCommand(ModCmd)
+	RootCmd.AddCommand(DefCmd)
+	RootCmd.AddCommand(EvalCmd)
+	RootCmd.AddCommand(ExportCmd)
+	RootCmd.AddCommand(VetCmd)
 	RootCmd.AddCommand(ChatCmd)
 	RootCmd.AddCommand(RunCmd)
+	RootCmd.AddCommand(TuiCmd)
 	RootCmd.AddCommand(FeedbackCmd)
 
 }
@@ -172,7 +173,7 @@ func RunErr() error {
 	return RootCmd.Execute()
 }
 
-const RootCustomHelp = `hof - the high code framework
+const RootCustomHelp = `hof - the higher order framework
 
   Learn more at https://docs.hofstadter.io
 
@@ -180,13 +181,18 @@ Usage:
   hof [flags] [command] [args]
 
 Main commands:
-  create                dynamic app blueprints from any git repo
-  datamodel             manage, diff, and migrate your data models
-  gen                   modular and composable code gen: CUE & data + templates = _
-  flow                  run CUE pipelines with the hof/flow DAG engine
-  fmt                   format any code and manage the formatters
-  mod                   CUE dependency management based on Go mods
   chat                  co-create with AI (alpha)
+  create                starter kits or blueprints from any git repo
+  datamodel             manage, diff, and migrate your data models
+  def                   print consolidated CUE definitions
+  eval                  evaluate and print CUE configuration
+  export                output data in a standard format
+  flow                  run workflows and tasks powered by CUE
+  fmt                   format any code and manage the formatters
+  gen                   CUE powered code generation
+  mod                   CUE module dependency management
+  tui                   a terminal interface to Hof and CUE
+  vet                   validate data with CUE
 
 Additional commands:
   help                  help about any command
