@@ -11,20 +11,12 @@ import (
 	"github.com/hofstadter-io/hof/cmd/hof/ga"
 )
 
-var runLong = `HofLineScript (HLS) run polyglot command and scripts seamlessly across runtimes
-
-can accept cue & flags or just a .hls file
-`
+var runLong = `Extended implementation of Testsuite	`
 
 func init() {
 
-	RunCmd.Flags().BoolVarP(&(flags.RunFlags.List), "list", "", false, "list matching scripts that would run")
-	RunCmd.Flags().BoolVarP(&(flags.RunFlags.Info), "info", "", false, "view detailed info for matching scripts")
-	RunCmd.Flags().StringSliceVarP(&(flags.RunFlags.Suite), "suite", "s", nil, "<name>: _ @run(suite)'s to run")
-	RunCmd.Flags().StringSliceVarP(&(flags.RunFlags.Runner), "runner", "r", nil, "<name>: _ @run(script)'s to run")
-	RunCmd.Flags().StringSliceVarP(&(flags.RunFlags.Environment), "env", "e", nil, "exrta environment variables for scripts")
-	RunCmd.Flags().StringSliceVarP(&(flags.RunFlags.Data), "data", "d", nil, "exrta data to include in the scripts context")
-	RunCmd.Flags().StringVarP(&(flags.RunFlags.Workdir), "workdir", "w", "", "working directory")
+	flags.SetupRunFlags(RunCmd.Flags(), &(flags.RunFlags))
+
 }
 
 func RunRun(args []string) (err error) {
