@@ -106,8 +106,8 @@ Datamodel: sql.Datamodel & {
 
 func init() {
 
-	DatamodelCmd.PersistentFlags().StringSliceVarP(&(flags.DatamodelPflags.Datamodels), "datamodel", "d", nil, "specify one or more datamodels to operate on")
-	DatamodelCmd.PersistentFlags().StringSliceVarP(&(flags.DatamodelPflags.Expression), "expr", "e", nil, "CUE paths to select outputs, depending on the command")
+	flags.SetupDatamodelPflags(DatamodelCmd.PersistentFlags(), &(flags.DatamodelPflags))
+
 }
 
 var DatamodelCmd = &cobra.Command{
