@@ -84,22 +84,12 @@ var genLong = `hof unifies CUE with Go's text/template system and diff3
 
 # Compose code gen mappings into reusable modules with
   hof gen app.cue -G frontend -G backend -G migrations -T ...
-  https://docs.hofstadter.io/first-example/`
+  https://docs.hofstadter.io/the-walkthrough/`
 
 func init() {
 
-	GenCmd.Flags().BoolVarP(&(flags.GenFlags.Stats), "stats", "s", false, "print generator statistics")
-	GenCmd.Flags().StringSliceVarP(&(flags.GenFlags.Generator), "generator", "G", nil, "generator tags to run, default is all, or none if -T is used")
-	GenCmd.Flags().StringArrayVarP(&(flags.GenFlags.Template), "template", "T", nil, "template mapping to render, see help for format")
-	GenCmd.Flags().StringSliceVarP(&(flags.GenFlags.Partial), "partial", "P", nil, "file globs to partial templates to register with the templates")
-	GenCmd.Flags().BoolVarP(&(flags.GenFlags.Diff3), "diff3", "D", false, "enable diff3 support for custom code")
-	GenCmd.Flags().BoolVarP(&(flags.GenFlags.NoFormat), "no-format", "", false, "disable formatting during code gen (ad-hoc only)")
-	GenCmd.Flags().BoolVarP(&(flags.GenFlags.KeepDeleted), "keep-deleted", "", false, "keep files that would be deleted after code generation")
-	GenCmd.Flags().BoolVarP(&(flags.GenFlags.Watch), "watch", "w", false, "run in watch mode, regenerating when files change, implied by -W/X")
-	GenCmd.Flags().StringSliceVarP(&(flags.GenFlags.WatchFull), "watch-globs", "W", nil, "filepath globs to watch for changes and trigger full regen")
-	GenCmd.Flags().StringSliceVarP(&(flags.GenFlags.WatchFast), "watch-fast", "X", nil, "filepath globs to watch for changes and trigger fast regen")
-	GenCmd.Flags().StringVarP(&(flags.GenFlags.AsModule), "as-module", "", "", "<github.com/username/<name>> like value for the generator module made from the given flags")
-	GenCmd.Flags().StringVarP(&(flags.GenFlags.Outdir), "outdir", "O", "", "base directory to write all output u")
+	flags.SetupGenFlags(GenCmd.Flags(), &(flags.GenFlags))
+
 }
 
 func GenRun(args []string) (err error) {
@@ -120,7 +110,7 @@ var GenCmd = &cobra.Command{
 		"G",
 	},
 
-	Short: "modular and composable code gen: CUE & data + templates = _",
+	Short: "CUE powered code generation",
 
 	Long: genLong,
 
