@@ -8,9 +8,9 @@ import (
 	"github.com/hofstadter-io/hof/flow/middleware/sync"
 )
 
-func UseDefaults(ctx *hofcontext.Context, opts *flags.RootPflagpole, popts *flags.FlowFlagpole) {
+func UseDefaults(ctx *hofcontext.Context, opts flags.RootPflagpole, popts flags.FlowPflagpole) {
 	// ctx.Use(dummy.NewDummy(opts, popts))
-	ctx.Use(info.NewPrint(opts, popts))
+	// ctx.Use(info.NewPrint(opts, popts))
 	ctx.Use(info.NewProgress(opts, popts))
 	//ctx.Use(info.NewBookkeeping(info.BookkeepingConfig{
 	//Workdir: ".hof/flow",
