@@ -11,6 +11,7 @@ import (
 	"cuelang.org/go/cue"
 
 	hofcontext "github.com/hofstadter-io/hof/flow/context"
+	"github.com/hofstadter-io/hof/lib/cuetils"
 )
 
 type Exec struct{}
@@ -24,6 +25,12 @@ func (T *Exec) Run(ctx *hofcontext.Context) (interface{}, error) {
 	v := ctx.Value
 	var cmd *exec.Cmd
 
+	init_schemas(v.Context())
+	// unify with schema
+	v = v.Unify(task_exec)
+	if v.Err() != nil {
+		return nil, cuetils.ExpandCueError(v.Err())
+	}
 	// TODO, rework how i/o works for exec
 
 	// todo, check failure modes, fill, not return error?
@@ -88,21 +95,13 @@ func (T *Exec) Run(ctx *hofcontext.Context) (interface{}, error) {
 	//
 	// run command
 	//
-	err = cmd.Run()
+	rerr := cmd.Run()
 
 	// TODO, how to run in the background and wait for signal?
 
 	// build return value
 	ret := make(map[string]interface{})
 
-	if err != nil {
-		if doExit  {
-			return nil, err
-		}
-
-		ret["error"] = err.Error()
-	}
-
 	//
 	// possibly fill stdout/stderr
 	//
@@ -115,6 +114,16 @@ func (T *Exec) Run(ctx *hofcontext.Context) (interface{}, error) {
 	ret["exitcode"] = cmd.ProcessState.ExitCode()
 	ret["success"] = cmd.ProcessState.Success()
 
+
+	if rerr != nil {
+		ret["error"] = rerr.Error()
+		if doExit  {
+			fmt.Printf("In %v\n%v", v.Path(), ret)
+			return ret, rerr
+		} else if ctx.ShowErrors {
+			fmt.Printf("In %v\n%v", v.Path(), ret)
+		}
+	}
 	return ret, nil
 }
 
