@@ -25,6 +25,7 @@ import (
 	gencmd "github.com/hofstadter-io/hof/lib/gen/cmd"
 	"github.com/hofstadter-io/hof/lib/repos/cache"
 	"github.com/hofstadter-io/hof/lib/mod"
+	"github.com/hofstadter-io/hof/lib/prompt"
 	"github.com/hofstadter-io/hof/lib/repos/remote"
 	"github.com/hofstadter-io/hof/lib/runtime"
 	"github.com/hofstadter-io/hof/lib/yagu"
@@ -172,6 +173,11 @@ func Create(module string, extra []string, rootflags flags.RootPflagpole, cmdfla
 	*/
 	genflags.Outdir = outdir
 
+	// HACK, pull off InputData so that it is not part of Runtime.Load()
+	// The input flags are different for create right now, and go somewhere else
+	inputs := rootflags.InputData
+	rootflags.InputData = []string{}
+
 	// create our runtime now, maybe we want a new func for this
 	//   since we want to ignore any current CUE module context
 	//   everything is put into a temp dir and rendered to CWD
@@ -195,7 +201,7 @@ func Create(module string, extra []string, rootflags flags.RootPflagpole, cmdfla
 	}
 
 	// fmt.Println("pre-run-creator")
-	err = runCreator(R, extra, cmdflags.Input)
+	err = runCreator(R, cmdflags, extra, inputs)
 	// fmt.Println("post-run-creator")
 	return err
 }
@@ -303,7 +309,11 @@ func setupTmpdir(url, ver string) (tmpdir, subdir string, err error) {
 	return tmpdir, subdir, err
 }
 
-func runCreator(R *gencmd.Runtime, extra, inputs []string) (err error) {
+func runCreator(R *gencmd.Runtime, cflags flags.CreateFlagpole, extra, inputs []string) (err error) {
+
+	if R.Flags.Verbosity > 0 {
+		fmt.Println("running creator with:", extra, inputs)
+	}
 
 	if len(R.Generators) == 0 {
 		return fmt.Errorf("no generators found, please make sure there is a creator at the root of the repository")
@@ -327,7 +337,7 @@ func runCreator(R *gencmd.Runtime, extra, inputs []string) (err error) {
 	// handle create input / prompt
 	for _, G := range R.Generators {
 		// update G locally
-		err = handleGeneratorCreate(G, R.Flags, extra, inputMap)
+		err = handleGeneratorCreate(G, R.Flags, cflags, extra, inputMap)
 		if err != nil {
 			return err
 		}
@@ -378,44 +388,50 @@ func runCreator(R *gencmd.Runtime, extra, inputs []string) (err error) {
 	for _, G := range R.Generators {
 
 		// maybe run post exec per creator
-		postExec := G.CueValue.LookupPath(cue.ParsePath("Create.PostExec"))
-		if postExec.Exists() {
+		postFlow := G.CueValue.LookupPath(cue.ParsePath("Create.PostFlow"))
+		if postFlow.Exists() {
 			if R.Flags.Verbosity > 0 {
-				fmt.Println("running post exec flow:", postExec)
+				fmt.Println("running post-flow:", postFlow)
 			}
-			ctx := flowcontext.New()
-			ctx.RootValue = postExec
-			ctx.Stdin = os.Stdin
-			ctx.Stdout = os.Stdout
-			ctx.Stderr = os.Stderr
-			ctx.Verbosity = R.Flags.Verbosity
+			if !cflags.Exec {
+				fmt.Println("skipping post-flow, use --exec to run")
+				// TODO, add prompt here to allow, after printing it
+				// apply to all?
+			} else {
+				ctx := flowcontext.New()
+				ctx.RootValue = postFlow
+				ctx.Stdin = os.Stdin
+				ctx.Stdout = os.Stdout
+				ctx.Stderr = os.Stderr
+				ctx.Verbosity = R.Flags.Verbosity
 
-			// how to inject tags into original value
-			// fill / return value
-			middleware.UseDefaults(ctx, &R.Flags, &flags.FlowFlags)
-			tasks.RegisterDefaults(ctx)
+				// how to inject tags into original value
+				// fill / return value
+				middleware.UseDefaults(ctx, R.Flags, flags.FlowPflags)
+				tasks.RegisterDefaults(ctx)
 
-			p, err := flow.NewFlow(ctx, postExec)
-			if err != nil {
-				return err
+				p, err := flow.OldFlow(ctx, postFlow)
+				if err != nil {
+					return err
+				}
+
+				err = p.Start()
+				if err != nil {
+					return err
+				}
+
+				G.CueValue = G.CueValue.FillPath(cue.ParsePath("Create.PostFlow"), postFlow)
+				if G.CueValue.Err() != nil {
+					return err
+				}
 			}
 
-			err = p.Start()
-			if err != nil {
-				return err
-			}
-
-			G.CueValue = G.CueValue.FillPath(cue.ParsePath("Create.PostExec"), postExec)
-			if G.CueValue.Err() != nil {
-				return err
-			}
-
-		} else if !postExec.Exists() {
+		} else if !postFlow.Exists() {
 			if G.Verbosity > 0 {
 				fmt.Println("post-exec not found")
 			}
-		} else if postExec.Err() != nil {
-			return postExec.Err()
+		} else if postFlow.Err() != nil {
+			return postFlow.Err()
 		}
 
 		// print final message to user
@@ -487,51 +503,57 @@ func loadCreateInputs(R *gencmd.Runtime, inputFlags []string) (input map[string]
 }
 
 
-func handleGeneratorCreate(G *gen.Generator, rflags flags.RootPflagpole, extraArgs []string, inputMap map[string]any) (err error) {
+func handleGeneratorCreate(G *gen.Generator, rflags flags.RootPflagpole, cflags flags.CreateFlagpole, extraArgs []string, inputMap map[string]any) (err error) {
 
 	// fill any extra args into generator value
 	G.CueValue = G.CueValue.FillPath(cue.ParsePath("Create.Args"), extraArgs)
 
+
 	// maybe run the pre flow
-	preExec := G.CueValue.LookupPath(cue.ParsePath("Create.PreExec"))
-	if preExec.Exists() {
+	preFlow := G.CueValue.LookupPath(cue.ParsePath("Create.PreFlow"))
+	if preFlow.Exists() {
 		if G.Verbosity > 0 {
-			fmt.Println("running pre exec flow:", preExec)
+			fmt.Println("running pre-flow:", preFlow)
+		}
+		if !cflags.Exec {
+			fmt.Println("skipping pre-flow, use --exec to run")
+				// TODO, add prompt here to allow, after printing it
+		} else {
+
+			ctx := flowcontext.New()
+			ctx.RootValue = preFlow
+			ctx.Stdin = os.Stdin
+			ctx.Stdout = os.Stdout
+			ctx.Stderr = os.Stderr
+			ctx.Verbosity = G.Verbosity
+
+			// how to inject tags into original value
+			// fill / return value
+			middleware.UseDefaults(ctx, rflags, flags.FlowPflags)
+			tasks.RegisterDefaults(ctx)
+
+			p, err := flow.OldFlow(ctx, preFlow)
+			if err != nil {
+				return err
+			}
+
+			err = p.Start()
+			if err != nil {
+				return err
+			}
+
+			G.CueValue = G.CueValue.FillPath(cue.ParsePath("Create.PreFlow"), preFlow)
+			if G.CueValue.Err() != nil {
+				return err
+			}
 		}
 
-		ctx := flowcontext.New()
-		ctx.RootValue = preExec
-		ctx.Stdin = os.Stdin
-		ctx.Stdout = os.Stdout
-		ctx.Stderr = os.Stderr
-		ctx.Verbosity = G.Verbosity
-
-		// how to inject tags into original value
-		// fill / return value
-		middleware.UseDefaults(ctx, &rflags, &flags.FlowFlags)
-		tasks.RegisterDefaults(ctx)
-
-		p, err := flow.NewFlow(ctx, preExec)
-		if err != nil {
-			return err
-		}
-
-		err = p.Start()
-		if err != nil {
-			return err
-		}
-
-		G.CueValue = G.CueValue.FillPath(cue.ParsePath("Create.PreExec"), preExec)
-		if G.CueValue.Err() != nil {
-			return err
-		}
-
-	} else if !preExec.Exists() {
+	} else if !preFlow.Exists() {
 		if G.Verbosity > 0 {
 			fmt.Println("no pre-exec...")
 		}
-	} else if preExec.Err() != nil {
-		return preExec.Err()
+	} else if preFlow.Err() != nil {
+		return preFlow.Err()
 	}
 
 	// make a local to gen value
@@ -617,7 +639,7 @@ func handleGeneratorCreate(G *gen.Generator, rflags flags.RootPflagpole, extraAr
 		G.CueValue = G.CueValue.FillPath(cue.ParsePath("Create.Input"), newMap)
 	}
 
-	G.CueValue, err = runPrompt(G.CueValue)
+	G.CueValue, err = prompt.RunCreatePrompt(G.CueValue)
 	if err != nil {
 		return err
 	}
