@@ -1,6 +1,10 @@
 package cuetils
 
 import (
+	"os"
+	"strings"
+
+	"cuelang.org/go/cue/ast"
 	"cuelang.org/go/cue/load"
 
 	"github.com/hofstadter-io/hof/cmd/hof/flags"
@@ -16,12 +20,14 @@ func CueRuntimeFromEntrypoints(entrypoints []string) (crt *CueRuntime, err error
 			Module:     "",
 			Package:    "",
 			Dir:        "",
-			BuildTags:  []string{},
+			Tags:       []string{},
+			TagVars:    load.DefaultTagVars(),
 			Tests:      false,
 			Tools:      false,
 			DataFiles:  false,
 			Overlay:    map[string]load.Source{},
 		},
+		dataMappings: make(map[string]string),
 	}
 
 	err = crt.Load()
@@ -32,29 +38,45 @@ func CueRuntimeFromEntrypoints(entrypoints []string) (crt *CueRuntime, err error
 // CueRuntimeFromArgsAndFlags builds up a CueRuntime
 //  by processing the args passed in AND the current flag values
 func CueRuntimeFromEntrypointsAndFlags(entrypoints []string) (crt *CueRuntime, err error) {
+	rflags := flags.RootPflags
 	cfg := &load.Config{
 		ModuleRoot: "",
 		Module:     "",
 		Package:    "",
 		Dir:        "",
-		BuildTags:  []string{},
+		Tags:       rflags.Tags,
+		TagVars:    load.DefaultTagVars(),
 		Tests:      false,
 		Tools:      false,
 		DataFiles:  false,
-		Overlay:    map[string]load.Source{},
+		Overlay:    make(map[string]load.Source),
 	}
 
 	// package?
-	if flags.RootPflags.Package != "" {
-		cfg.Package = flags.RootPflags.Package
+	if rflags.Package != "" {
+		cfg.Package = rflags.Package
+	}
+	if rflags.InjectEnv {
+		for _, e := range os.Environ() {
+			parts := strings.Split(e, "=")
+			k,v := parts[0], parts[1]
+			cfg.TagVars[k] = load.TagVar{
+				Func: func() (ast.Expr, error) {
+					return ast.NewString(v), nil
+				},
+			}
+		}
 	}
 
 	crt = &CueRuntime{
 		Entrypoints: entrypoints,
 		CueConfig:   cfg,
+		IncludeData: rflags.IncludeData,
+		dataMappings: make(map[string]string),
 	}
 
 	err = crt.Load()
 
 	return crt, err
 }
+
