@@ -1,6 +1,8 @@
 package structural
 
 import (
+	"fmt"
+
 	"cuelang.org/go/cue"
 )
 
@@ -44,7 +46,9 @@ func diffStruct(orig, next cue.Value, opts *Options) (cue.Value, bool) {
 	iter, _ := orig.Fields(defaultWalkOptions...)
 	for iter.Next() {
 		s := iter.Selector()
-		p := cue.MakePath(s)
+		// HACK, this works around a bug in CUE
+		// p := cue.MakePath(s)
+		p := cue.ParsePath(fmt.Sprint(s))
 		u := next.LookupPath(p)
 
 		// check that field exists in from. Should we be checking f.Err()?
@@ -65,7 +69,9 @@ func diffStruct(orig, next cue.Value, opts *Options) (cue.Value, bool) {
 	iter, _ = next.Fields(defaultWalkOptions...)
 	for iter.Next() {
 		s := iter.Selector()
-		p := cue.MakePath(s)
+		// HACK, this works around a bug in CUE
+		// p := cue.MakePath(s)
+		p := cue.ParsePath(fmt.Sprint(s))
 		v := orig.LookupPath(p)
 
 		// check that field exists in from. Should we be checking f.Err()?
@@ -112,6 +118,22 @@ func diffList(orig, next cue.Value, opts *Options) (cue.Value, bool) {
 }
 
 func diffLeaf(orig, next cue.Value, opts *Options) (cue.Value, bool) {
+	if orig.IncompleteKind() == next.IncompleteKind() {
+		if orig.IsConcrete() == next.IsConcrete() {
+			u := orig.Unify(next)
+			if u.Err() == nil {
+				return cue.Value{}, false
+			}
+		}
+	}
+
+	// need to know if this is a basic lit, so we know if we are changing a concrete value
+	ctx := orig.Context()
+	ret := ctx.CompileString("{}")
+	ret = ret.FillPath(cue.ParsePath("\"-\""), orig)
+	ret = ret.FillPath(cue.ParsePath("\"+\""), next)
+
+	/*
 	ctx := orig.Context()
 	ret := newStruct(ctx)
 	lbl := GetLabel(orig)
@@ -134,6 +156,7 @@ func diffLeaf(orig, next cue.Value, opts *Options) (cue.Value, bool) {
 	add := newStruct(ctx)
 	add = add.FillPath(cue.MakePath(lbl), next)
 	ret = ret.FillPath(cue.ParsePath("\"+\""), add)
+	*/
 
 	return ret, true
 }
