@@ -61,8 +61,12 @@ func (ts *Script) CmdEnv(neg int, args []string) {
 		}
 
 		// else, split and do things
-		k, v := env[:i], env[i+1:]
-		if v[0] == '@' {
+		parts := strings.Split(env, "=")
+		k, v := parts[0], ""
+		if len(parts) > 1 {
+			v = parts[1]
+		}
+		if len(v) > 0 && v[0] == '@' {
 			fname := v[1:] // for error messages
 			if fname == "stdout" {
 				v = ts.stdout
@@ -144,7 +148,7 @@ func (ts *Script) MkAbs(file string) string {
 }
 
 // ReadFile returns the contents of the file with the
-// given name, intepreted relative to the test script's
+// given name, interpreted relative to the test script's
 // current directory. It interprets "stdout" and "stderr" to
 // mean the standard output or standard error from
 // the most recent exec or wait command respectively.
